@@ -1,23 +1,25 @@
 #' Define a ctsem model
 #' 
 #' This function is used to specify a continuous time structural equation model, 
-#' which can then be fit to data with function \code{\link{ctFit}}.  
+#' which can then be fit to data with function \code{\link{ctFit}}, or \code{\link{ctStanFit}}
+#' for Bayesian models.
+#' 
+#' @param type character string. If 'omx' (default) configures model for maximum likelihood fitting with ctFit, using OpenMx. 
+#' If 'stanct' or 'standt' configures either continuous ('stanct') or discrete ('standt') time 
+#' model for Bayesian fitting with \code{\link{ctStanFit}}, using Stan.
+#' 
 #' @param n.manifest Number of manifest indicators per individual at each measurement occasion / time point.  
 #' Manifest variables are included as the first element of the wide data matrix, with all the 1:n.manifest manifest variables 
 #' at time 1 followed by those of time 2, and so on.
 #' 
 #' @param n.latent Number of latent processes.
 #' 
-#' @param Tpoints Number of time points, or measurement occasions, in the data.  This will generally be the maximum 
-#' number of time points for a single individual, but may be one extra if sample relative time intervals are used, 
-#' see \code{\link{ctIntervalise}}.  
-#' 
 #' @param LAMBDA n.manifest*n.latent loading matrix relating latent to manifest variables, 
 #' with latent processes 1:n.latent along the columns, and manifest variables
 #' 1:n.manifest in the rows.
 #' 
 #' @param manifestNames n.manifest length vector of manifest variable names as they appear in the data structure, 
-#' without the _Tx time point suffix.  Defaults to Y1, Y2, etc.
+#' without any _Tx time point suffix that may be present in wide data.  Defaults to Y1, Y2, etc.
 #' 
 #' @param latentNames n.latent length vector of latent variable names 
 #' (used for naming parameters, defaults to eta1, eta2, etc).
@@ -28,9 +30,8 @@
 #' @param T0MEANS n.latent*1 matrix of latent process means at first time point, T0. 
 #' "auto" freely estimates all parameters.
 #' 
-#' @param MANIFESTMEANS n.manifest*1 matrix of manifest means.  
-#' "auto" fixes all parameters to 0, but some may need to be freed (by specifying character labels) when a process has multiple indicators.
-#' 'free' frees all parameters - identification problems may result if CINT is also free (default).
+#' @param MANIFESTMEANS n.manifest*1 matrix of manifest intercept parameters.  
+#' "auto" frees all parameters.
 #' 
 #' @param MANIFESTVAR lower triangular n.manifest*n.manifest cholesky matrix of variance / covariance 
 #' between manifests at each measurement occasion (i.e. measurement error / residual).  
@@ -41,34 +42,44 @@
 #' relating the processes over time. 
 #' "auto" freely estimates all parameters.
 #' 
-#' @param CINT n.latent * 1 matrix of continuous intercepts, allowing for non 0 
-#' asymptotic levels of the processes.  
-#' "auto" freely estimates all parameters.
+#' @param CINT n.latent * 1 matrix of latent process intercepts, allowing for non 0 
+#' asymptotic levels of the latent processes. Generally only necessary for additional trends and more complex dynamics.
+#' "auto" fixes all parameters to 0.
 #' 
 #' @param DIFFUSION lower triangular n.latent*n.latent cholesky matrix of diffusion process 
 #' variance and covariance (latent error / dynamic innovation).
 #' "auto" freely estimates all parameters.
 #' 
-#' @param TRAITVAR Either NULL, if no trait / individual heterogeneity effect, 
+#' @param n.TIpred Number of time independent predictors. 
+#' Each TIpredictor is inserted at the right of the data matrix, after the time intervals.
+#' 
+#' @param TIpredNames n.TIpred length vector of time independent predictor variable names,
+#' as they appear in the data structure.  Default names are TI1, TI2, etc.
+#' 
+#' @param n.TDpred Number of time dependent predictor variables in the dataset.  
+#' 
+#' @param TDpredNames n.TDpred length vector of time dependent predictor variable names, 
+#' as they appear in the data structure, without any _Tx time point suffix that may appear in wide data.  
+#' Default names are TD1, TD2, etc.
+#' 
+#' @param Tpoints For type='omx' only. Number of time points, or measurement occasions, in the data.  This will generally be the maximum 
+#' number of time points for a single individual, but may be one extra if sample relative time intervals are used, 
+#' see \code{\link{ctIntervalise}}. 
+#' 
+#' @param TRAITVAR For type='omx' only. Either NULL, if no trait / individual heterogeneity effect, 
 #' or lower triangular n.latent*n.latent cholesky matrix of trait variance / covariance.
 #' "auto" freely estimates all parameters.
 #' 
-#' @param MANIFESTTRAITVAR either NULL (default) if no trait variance / individual heterogeneity in the level of
+#' @param T0TRAITEFFECT For type='omx' only. Either NULL, if no trait / individual heterogeneity effect, 
+#' or lower triangular n.latent*n.latent cholesky matrix of initial trait variance / covariance.
+#' "auto" freely estimates all parametrers.
+#' 
+#' @param MANIFESTTRAITVAR For type='omx' only. Either NULL (default) if no trait variance / individual heterogeneity in the level of
 #' the manifest indicators, otherwise a lower triangular n.manifest * n.manifest variance / covariance matrix. 
 #' Set to "auto" to include and free all parameters - but identification problems will arise if \code{TRAITVAR} is 
 #' also set.
 #' 
-#' @param n.TDpred Number of time dependent predictors in the dataset.  
-#' Each time dependent predictor must have Tpoints-1 columns 
-#' (A value of a predictor at the final time point would not have any time to show an effect), 
-#' which are included in the data matrix after manifest variables,
-#' with the Tpoints-1 observations of the first predictor followed by those of the second and so on.
-#' 
-#' @param TDpredNames n.TDpred length vector of time dependent predictor variable names, 
-#' as they appear in the data structure, without the _Tx time point suffix.  
-#' Default names are TD1, TD2, etc.
-#' 
-#' @param TDPREDMEANS (n.TDpred * (Tpoints - 1)) rows * 1 column matrix of time dependent predictor means.
+#' @param TDPREDMEANS For type='omx' only. (n.TDpred * (Tpoints - 1)) rows * 1 column matrix of time dependent predictor means.
 #' If 'auto', the means are freely estimated.  Otherwise, 
 #' the means for the Tpoints-1 observations of your first time dependent predictor 
 #' are followed by those of TDpred 2, and so on.
@@ -77,56 +88,53 @@
 #' Effects from 1:n.TDpred columns TDpredictors go to 1:n.latent rows of latent processes.
 #' "auto" freely estimates all parameters.
 #' 
-#' @param T0TDPREDCOV n.latent rows * ((Tpoints-1) rows * n.TDpred) columns covariance matrix 
+#' @param T0TDPREDCOV For type='omx' only. n.latent rows * ((Tpoints-1) rows * n.TDpred) columns covariance matrix 
 #' between latents at T0 and time dependent predictors.
 #' "auto" freely estimates all parameters.
 #' 
-#' @param TDPREDVAR lower triangular (n.TDpred * (Tpoints-1)) rows * (n.TDpred * (Tpoints-1)) columns variance / covariance
+#' @param TDPREDVAR For type='omx' only. lower triangular (n.TDpred * (Tpoints-1)) rows * (n.TDpred * (Tpoints-1)) columns variance / covariance
 #' cholesky matrix for time dependent predictors.
 #' "auto" (default) freely estimates all parameters.
 #' 
-#' @param TRAITTDPREDCOV n.latent rows * (n.TDpred*(Tpoints-1)) columns covariance matrix of 
+#' @param TRAITTDPREDCOV For type='omx' only. n.latent rows * (n.TDpred*(Tpoints-1)) columns covariance matrix of 
 #' latent traits and time dependent predictors.  
 #' The Tpoints-1 columns of the first preditor are followed by those of the second and so on.
 #' Covariances with the trait variance of latent process 1 are specified in row 1, process 2 in row 2, etc.
 #' "auto" (default) freely estimates covariance between time dependent predictors and traits, 
 #' (if both exist, otherwise this matrix is set to NULL, and ignored in any case).
 #' 
-#' @param TDTIPREDCOV (n.TDpred * (Tpoints-1)) rows * n.TIpred columns covariance
+#' @param TDTIPREDCOV For type='omx' only. (n.TDpred * (Tpoints-1)) rows * n.TIpred columns covariance
 #' matrix between time dependent and time independent predictors.
 #' "auto" (default) freely estimates all parameters.
-#' 
-#' @param n.TIpred Number of time independent predictors. 
-#' Each TIpredictor is inserted at the right of the data matrix, after the time intervals.
-#' 
-#' @param TIpredNames n.TIpred length vector of time independent predictor variable names,
-#' as they appear in the data structure.  Default names are TI1, TI2, etc.
 #'  
-#' @param TIPREDMEANS n.TIpred * 1 matrix of time independent predictor means.
+#' @param TIPREDMEANS For type='omx' only. n.TIpred * 1 matrix of time independent predictor means.
 #' If 'auto', the means are freely estimated.  
 #' 
-#' @param TIPREDEFFECT n.latent*n.TIpred effect matrix of time independent predictors on latent processes.
-#' "auto" freely estimates all parameters and generates starting values.
+#' @param TIPREDEFFECT For type='omx' only. n.latent*n.TIpred effect matrix of time independent predictors on latent processes.
+#' "auto" freely estimates all parameters and generates starting values. TIPREDEFFECT parameters for type='stan' are estimated
+#' by default on all subject level parameters, to restrict this, 
+#' manually edit the model object after creation.
 #' 
-#' @param T0TIPREDEFFECT n.latent*n.TIpred effect matrix of time independent 
+#' @param T0TIPREDEFFECT For type='omx' only.n.latent*n.TIpred effect matrix of time independent 
 #' predictors on latents at T0. "auto" freely estimates all parameters, though note that under the default 
 #' setting of \code{stationary} for \code{ctFit}, this matrix is ignored as the effects are determined based on
 #' the overall process parameters.
 #' 
-#' @param TIPREDVAR lower triangular n.TIpred * n.TIpred Cholesky decomposed covariance
+#' @param TIPREDVAR For type='omx' only.lower triangular n.TIpred * n.TIpred Cholesky decomposed covariance
 #' matrix for all time independent predictors.
 #' "auto" (default) freely estimates all parameters.
 #' 
-#' @param startValues a named vector, where the names of each value must match a parameter in the specified model,
+#' @param startValues For type='omx' only. A named vector, where the names of each value must match a parameter in the specified model,
 #' and the value sets the starting value for that parameter during optimization.
 #' If not set, random starting values representing relatively stable processes with small effects and 
 #' covariances are generated by ctFit.  
 #' Better starting values may improve model fit speed and the chance of an appropriate model fit. 
 #' 
-#' @param timeVarying character vector of matrices to allow to vary over measurement occasions. Currently only accepts 'MANIFESTMEANS'. 
+#' @param timeVarying For type='omx' only. character vector of matrices to allow to vary over measurement occasions. Currently only accepts 'MANIFESTMEANS'. 
 #' @examples 
-#' 
-#'  ### impulse and level change time dependent predictor example from Driver, Oud, Voelkle (2015)
+#'  ### Frequentist example:
+#'  ### impulse and level change time dependent predictor 
+#'  ### example from Driver, Oud, Voelkle (2015)
 #'  data('ctExample2')
 #'  tdpredmodel <- ctModel(n.manifest = 2, n.latent = 3, n.TDpred = 1, 
 #'  Tpoints = 8, manifestNames = c('LeisureTime', 'Happiness'), 
@@ -146,24 +154,30 @@
 #'  tdpredmodel$T0MEANS[3] <- 0
 #'  tdpredmodel$TDPREDEFFECT[3, ] <- 1
 #'  tdpredmodel$DRIFT[3, ] <- 0
+#'  
+#'  
+#' ###Bayesian example:
+#' model<-ctModel(type='stanct',
+#' n.latent=2, latentNames=c('eta1','eta2'),
+#' n.manifest=2, manifestNames=c('Y1','Y2'),
+#' n.TDpred=1, TDpredNames='TD1', 
+#' n.TIpred=3, TIpredNames=c('TI1','TI2','TI3'),
+#' LAMBDA=diag(2))
 #'
-#'  \dontrun{
-#'  tdpredfit <- ctFit(datawide = ctExample2, ctmodelobj = tdpredmodel)
-#'
-#'  summary(tdpredfit)
-#'  }
 #' 
 #' @export
 
-ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA, 
+ctModel<-function(n.manifest, n.latent, LAMBDA, type='omx', Tpoints=NULL, 
   manifestNames='auto', latentNames='auto', 
   T0VAR="auto", T0MEANS="auto", MANIFESTMEANS="auto", MANIFESTVAR="auto", 
   DRIFT="auto", CINT="auto", DIFFUSION="auto",
-  TRAITVAR=NULL, MANIFESTTRAITVAR=NULL,
-  n.TDpred=0, TDpredNames='auto', TDPREDMEANS="auto", TDPREDEFFECT="auto", 
+  n.TDpred=0, TDpredNames='auto', n.TIpred=0, TIpredNames='auto',
+  TRAITVAR=NULL, T0TRAITEFFECT=NULL,
+  MANIFESTTRAITVAR=NULL,
+  TDPREDMEANS="auto", TDPREDEFFECT="auto", 
   T0TDPREDCOV="auto", TDPREDVAR="auto",  
   TRAITTDPREDCOV="auto", TDTIPREDCOV='auto',
-  n.TIpred=0, TIpredNames='auto', TIPREDMEANS="auto", TIPREDEFFECT="auto", 
+  TIPREDMEANS="auto", TIPREDEFFECT="auto", 
   T0TIPREDEFFECT="auto", TIPREDVAR="auto", 
   startValues=NULL, timeVarying=NULL){
   
@@ -193,13 +207,17 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
   
 
 
-  
+  if(type=='omx' & is.null(Tpoints)) stop('Type "omx" requires Tpoints specified!')
   
 
   
   
   ###### RUN SEQUENCE
   
+  if(type!='omx') Tpoints<-3
+  if(type=='omx' && is.null(Tpoints)) stop('Tpoints must be specified for type="omx"')
+  if(!(type %in% c('stanct','standt','omx'))) stop('type must be either omx, stanct, or standt
+    !')
   
   #names
   if(all(manifestNames=='auto')) manifestNames=paste0('Y',1:n.manifest)
@@ -245,9 +263,8 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
   
   
   
-  
-  if(MANIFESTMEANS[1]=="auto") MANIFESTMEANS<- matrix(0,nrow=n.manifest)
-  if(MANIFESTMEANS[1]=="free") MANIFESTMEANS<- ctLabel(TDpredNames=TDpredNames,TIpredNames=TIpredNames,
+
+  if(MANIFESTMEANS[1]=="auto") MANIFESTMEANS<- ctLabel(TDpredNames=TDpredNames,TIpredNames=TIpredNames,
     manifestNames=manifestNames,latentNames=latentNames,matrixname="MANIFESTMEANS",n.latent=n.latent,
     n.manifest=n.manifest,n.TDpred=n.TDpred,n.TIpred=n.TIpred,Tpoints=Tpoints)
   if(ncol(MANIFESTMEANS)>1) stop("Specified MANIFESTMEANS matrix has more than one column")
@@ -256,7 +273,7 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
   
   
   
-  
+  if(!is.na(MANIFESTVAR[1])){
   if(all(MANIFESTVAR=="auto")) {
     MANIFESTVAR<-ctLabel(TDpredNames=TDpredNames,TIpredNames=TIpredNames,
     manifestNames=manifestNames,latentNames=latentNames,matrixname="MANIFESTVAR",n.latent=n.latent,
@@ -271,7 +288,7 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
   }
   
   if(nrow(MANIFESTVAR)!=n.manifest | ncol(MANIFESTVAR)!=n.manifest) stop("Dimensions of MANIFESTVAR matrix are not n.manifest * n.manifest")
-  
+  }
   
   
   
@@ -284,10 +301,8 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
   
   
   
-  if(CINT[1]=="auto") CINT<-ctLabel(TDpredNames=TDpredNames,TIpredNames=TIpredNames,manifestNames=manifestNames,
-    latentNames=latentNames,matrixname="CINT",n.latent=n.latent,
-    n.manifest=n.manifest,n.TDpred=n.TDpred,n.TIpred=n.TIpred,Tpoints=Tpoints)
-  if(ncol(CINT)!=1 | nrow(CINT)!=n.latent) stop("Dimensions of CINT are not 1 * n.latent")
+  if(CINT[1]=="auto") CINT<-matrix(0,nrow=n.latent,ncol=1)
+  if(ncol(CINT)!=1 | nrow(CINT)!=n.latent) stop("Dimensions of CINT are not n.latent * 1")
   
   
   
@@ -302,9 +317,21 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
   
   
   
-  if(!is.null(TRAITVAR) && TRAITVAR[1]=="auto") TRAITVAR<-ctLabel(TDpredNames=TDpredNames,TIpredNames=TIpredNames,manifestNames=manifestNames,latentNames=latentNames,matrixname="TRAITVAR",n.latent=n.latent,
+  if(!is.null(TRAITVAR) && TRAITVAR[1]=="auto") TRAITVAR<-ctLabel(TDpredNames=TDpredNames,
+    TIpredNames=TIpredNames,manifestNames=manifestNames,latentNames=latentNames,matrixname="TRAITVAR",
+    n.latent=n.latent,n.manifest=n.manifest,n.TDpred=n.TDpred,n.TIpred=n.TIpred,Tpoints=Tpoints)
+  if(!is.null(TRAITVAR) && nrow(TRAITVAR)+ncol(TRAITVAR)!=n.latent*2) stop ("
+    Dimensions of TRAITVAR are not n.latent * n.latent")
+  
+  if(!is.null(TRAITVAR) && (is.null(T0TRAITEFFECT) || T0TRAITEFFECT[1] == 'auto')) T0TRAITEFFECT<-
+    ctLabel(TDpredNames=TDpredNames,TIpredNames=TIpredNames,manifestNames=manifestNames,
+      latentNames=latentNames,matrixname="T0TRAITEFFECT",n.latent=n.latent,
     n.manifest=n.manifest,n.TDpred=n.TDpred,n.TIpred=n.TIpred,Tpoints=Tpoints)
-  if(!is.null(TRAITVAR) && nrow(TRAITVAR)+ncol(TRAITVAR)!=n.latent*2) stop ("Dimensions of TRAITVAR are not n.latent * n.latent")
+  
+  if(!is.null(T0TRAITEFFECT) && nrow(T0TRAITEFFECT)+ncol(T0TRAITEFFECT)!=n.latent*2) stop ("Dimensions of TRAITVAR are not n.latent * n.latent")
+  
+  
+  
   
   
   
@@ -451,7 +478,7 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
     assign('tempmat',get(tempmatname))
     if(is.null(tempmat)) next
     if(all(suppressWarnings(as.numeric(tempmat[upper.tri(tempmat)])) %in% 0)) next
-    stop(paste0(tempmatname,' is not lower triangular! Covariance matrices must be specified in cholesky decomposed form.'))
+    stop(paste0(tempmatname,' is not lower triangular! Covariance type matrices must be specified in the appropriate lower-triangular form.'))
   }
   
  
@@ -467,7 +494,7 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
   completemodel<-list(n.manifest,n.latent,n.TDpred,n.TIpred,Tpoints,LAMBDA,
     manifestNames,latentNames,TDpredNames,TIpredNames,
     T0VAR,T0MEANS,MANIFESTMEANS,MANIFESTVAR,DRIFT,CINT,DIFFUSION,
-    TRAITVAR,MANIFESTTRAITVAR,
+    TRAITVAR,T0TRAITEFFECT,MANIFESTTRAITVAR,
     TDPREDEFFECT, TDPREDMEANS, T0TDPREDCOV, TRAITTDPREDCOV,
     TIPREDEFFECT, TIPREDMEANS, T0TIPREDEFFECT,
     TIPREDVAR, TDPREDVAR,TDTIPREDCOV,   
@@ -476,36 +503,18 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
   names(completemodel)<-c("n.manifest","n.latent","n.TDpred","n.TIpred","Tpoints","LAMBDA",
     "manifestNames","latentNames","TDpredNames","TIpredNames",
     "T0VAR","T0MEANS","MANIFESTMEANS","MANIFESTVAR","DRIFT","CINT","DIFFUSION",
-    "TRAITVAR","MANIFESTTRAITVAR",
+    "TRAITVAR",'T0TRAITEFFECT',"MANIFESTTRAITVAR",
     'TDPREDEFFECT', 'TDPREDMEANS', 'T0TDPREDCOV', 'TRAITTDPREDCOV',
     'TIPREDEFFECT', 'TIPREDMEANS', 'T0TIPREDEFFECT',
     'TIPREDVAR', 'TDPREDVAR','TDTIPREDCOV',  
     "startValues", 'timeVarying')
   
+
   
   
-#   if(initsToFixed==TRUE){ #if we want to take init params as fixed instead - can be a simple way to vary models
-#     
-#     for( i in 1:length(completemodel)){
-#       
-#       if(is.matrix(completemodel[[i]])){
-#         
-#         fixed<-completemodel[[i]]
-# 
-#         
-#         if(!is.null(startValues)){ #if there are some startValues specified, check each part of x
-#           for( j in 1:length(startValues)){
-#             
-#               fixed[grepl(names(startValues)[j], fixed)] <- startValues[j]
-#           }
-#         }
-#         
-#         completemodel[[i]]<-fixed     
-#       }
-#   }
-#   }
+  if(type=='omx') class(completemodel)<-"ctsemInit"
   
+  if(type=='stanct' | type=='standt') completemodel<-ctStanModel(completemodel,type=type)
   
-  class(completemodel)<-"ctsemInit"
   return(completemodel)
-}
\ No newline at end of file
+}
